// This code is distributed under the terms of the GNU General Public License.

using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Runtime.InteropServices;
using System.Text;
using System.IO;

namespace PhoneNumberFormatter
{
    static class Program
    {
        public static string InstallDir = Path.GetDirectoryName(Application.ExecutablePath);
        public static string SettingsINI = InstallDir + "\\settings.ini";
        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            Application.EnableVisualStyles();
            Application.SetCompatibleTextRenderingDefault(false);
            //Application.Run(new Form1());
            string config_verified = ReadINI("settings", "config_verified", SettingsINI);
            if (config_verified != "1")
            {
                MessageBox.Show("This utility will read the text that you have copied to the clipboard, which is presumably a phone number. It will change the format of this phone number, and then it will copy the new number to the clipboard, allowing you to paste it into your application. All of this will happen in the background. The utility will open for a second, copy the new number to the clipboard, and then close." + Environment.NewLine + Environment.NewLine + "Please open this utility's folder, open the settings.ini file, and configure your settings. One configured, set config_verified=1, save and close file, and then relaunch this utility." + Environment.NewLine + Environment.NewLine + "Example on how to use:" + Environment.NewLine + "1. Add a keyword to Keybreeze that points to the 'Phone Number Formatter.exe' file." + Environment.NewLine + "2. Copy a phone number from any application, such as (816) 456-7890." + Environment.NewLine + "3. Press the Keybreeze hotkey, type the keyword, and press Enter." + Environment.NewLine + "4. Go to your application and paste the phone number. It will be pasted as 918164567890." + Environment.NewLine + Environment.NewLine + "This utility will now close. Please relaunch it after the configuration is verified.", "Phone Number Formatter");
                Application.Exit();
                return;
            }
            string clipboard_text = Clipboard.GetText().Trim();
            if (clipboard_text.Length == 0 || clipboard_text.Length > 100)
            {
                Application.Exit();
                return;
            }
            string remove_characters = ReadINI("settings", "remove_characters", SettingsINI);
            string prepend_characters = ReadINI("settings", "prepend_characters", SettingsINI);
            if (remove_characters.Length > 0)
            {
                for (int i = 0; i < remove_characters.Length; i++)
                {
                    string this_char = remove_characters.Substring(i, 1);
                    // remove this character in the clipboard text.
                    clipboard_text = clipboard_text.Replace(this_char, "");
                }
            }
            if (prepend_characters.Length > 0)
            {
                clipboard_text = prepend_characters + clipboard_text;
                // make sure we did not prepend 911 to the number.
                if (clipboard_text.IndexOf("911") == 0)
                {
                    clipboard_text = "91" + clipboard_text.Substring(3);
                }
            }
            Clipboard.Clear();
            Clipboard.SetText(clipboard_text);
        }

        [DllImport("kernel32")]
        public static extern int GetPrivateProfileString(string section, string key, string def, StringBuilder retVal, int size, string filePath);

        [DllImport("KERNEL32.DLL", EntryPoint = "WritePrivateProfileStringW",
          SetLastError = true,
          CharSet = CharSet.Unicode, ExactSpelling = true,
          CallingConvention = CallingConvention.StdCall)]
        public static extern int WritePrivateProfileString(
          string lpAppName,
          string lpKeyName,
          string lpString,
          string lpFilename);

        public static string ReadINI(string Section, string Key, string thePath)
        {
            StringBuilder temp = new StringBuilder(255);
            int i = GetPrivateProfileString(Section, Key, "", temp, 255, thePath);
            return temp.ToString();
        }

        public static int ReadIntFromINI(string Section, string Key, string thePath, int set_default = -1)
        {
            // this will read an integer from an INI file. This function allows the option to 
            // set a default value to insert in case the value is currently blank in the INI.
            StringBuilder temp = new StringBuilder(255);
            int i = GetPrivateProfileString(Section, Key, "", temp, 255, thePath);
            string the_text = temp.ToString();
            try
            {
                return Convert.ToInt32(the_text);
            }
            catch
            {
                if (set_default != -1)
                    WriteINI(Section, Key, set_default.ToString(), thePath);
                else
                    set_default = 0;

                return set_default;
            }

        }

        public static int WriteINI(string Section, string Key, string Value, string thePath)
        {
            int try_once;
            try
            {
                try_once = WritePrivateProfileString(Section, Key, Value, thePath);
                if (try_once == 0)
                    return 0;
                else
                    return 1;
            }
            catch
            {
                return 0;
            }
        }
    }
}
